@@ -1,6 +1,6 @@
 #define DBHOST "localhost"
 #define DBUSER "radiusd"
-#define DBPASS "better-change-me"
+#define DBPASS "changeme"
 #define DBBASE "accounting"
 
 #define SELECT_PASSWD "SELECT passwd FROM users WHERE login='%s' AND status='Active'"
