@@ -28,7 +28,7 @@ CREATE TABLE logout (
 # Table structure for table 'users'
 #
 CREATE TABLE users (
-  login varchar(15),
+  login varchar(15) NOT NULL PRIMARY KEY,
   passwd varchar(14),
   name varchar(255),
   status enum('Active','Disabled') DEFAULT 'Active' NOT NULL
